Views — django-sphinxdoc 1.2.0 documentation

### Navigation

- index
- modules |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »

# Views

Views for django-shinxdoc.

`sphinxdoc.views.` `documentation`(request, slug, path)

  Displays the contents of a `sphinxdoc.models.Document`.

  `slug` specifies the project, the document belongs to, `path` is the path to the original JSON file relative to the builddir and without the file extension. `path` may also be a directory, so this view checks if `path/index` exists, before trying to load `path` directly.

`sphinxdoc.views.` `objects_inventory`(request, slug)

  Renders the `objects.inv` as plain text.

`sphinxdoc.views.` `sphinx_serve`(request, slug, type_, path)

  Serves sphinx static and other files.

class `sphinxdoc.views.` `ProjectSearchView`

  Inherits `SearchView` and handles a search request and displays the results as a simple list.

  `build_form`()

    Instantiates the form that should be used to process the search query.

  `extra_context`()

    Adds the project, the contents of `globalcontext.json` (env) and the update_date as extra context.

### Navigation

- index
- modules |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »